from distutils.core import setup
setup(
  name = 'Topsis_Ria_101903284',        
  packages = ['Topsis_Ria_101903284'],  
  version = 'v1.2',      
  license='MIT',       
  description = 'Topsis Score and Rank generator',
  author = 'Ria Sood',                
  author_email = 'rsood1_be19@thapar.edu',      
  url = 'https://github.com/riasood02/Topsis_Ria_101903284',   
  download_url = '',    
  keywords = ['topsis','topsis score','rank','Thapar'],
  install_requires=['numpy','pandas' ],
  classifiers=[
    'Development Status :: 3 - Alpha',    
    'Intended Audience :: Developers',   
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   
    'Programming Language :: Python :: 3',      
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)
